﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Web.UI;
using System.Web;

namespace ChartControl
{
    public class ChartControl : Control
    {
        private int _width = 400;
        private int _height = 300;
        private string _dataUrl;
        private bool _useSwfObject = false;

        private static readonly string _protocol;

        static ChartControl()
        {
            _protocol = "http";
            HttpContext context = HttpContext.Current;

            if (context != null && context.Request.ServerVariables["HTTPS"].Equals("on", StringComparison.OrdinalIgnoreCase))
                _protocol += "s";
        }

        #region Propiedades

        public int Width
        {
            get { return _width; }
            set { _width = value; }
        }
        public int Height
        {
            get { return _height; }
            set { _height = value; }
        }
        public string DataUrl
        {
            get { return _dataUrl; }
            set { _dataUrl = value; }
        }
        public bool UseSwfObject
        {
            get { return _useSwfObject; }
            set { _useSwfObject = value; }
        }

        #endregion

        protected override void OnInit(EventArgs e)
        {
            if (_useSwfObject)
            {
                Page.ClientScript.RegisterClientScriptInclude("swfobject",
                        Page.ClientScript.GetWebResourceUrl(GetType(), "ChartControl.Resources.swfobject.js"));
            }

            base.OnInit(e);
        }

        protected override void Render(HtmlTextWriter writer)
        {
            if (!DesignMode)
            {
                if (string.IsNullOrEmpty(_dataUrl))
                    throw new ArgumentException("DataUrl is null or empty.");

                StringBuilder output = new StringBuilder();
                string ofcResource = Page.ClientScript.GetWebResourceUrl(GetType(), "ChartControl.Resources.open-flash-chart.swf");

                
                string dataUrl = HttpUtility.UrlEncode(Page.ResolveUrl(_dataUrl));

                if (_useSwfObject)
                {
                    output.AppendFormat("<div id='{0}' onmouseout='onrollout();'></div>\n", ClientID);
                    output.Append("<script type='text/javascript'>\n");
                    output.AppendFormat("var so = new SWFObject('{0}', '{1}', '{2}', '{3}', '9', '#FFFFFF');\n",
                        ofcResource, ClientID, _width, _height);
                    output.AppendFormat("so.addVariable('width', '{0}');\n", _width);
                    output.AppendFormat("so.addVariable('height', '{0}');\n", _height);
                    output.AppendFormat("so.addVariable('data', '{0}');\n", dataUrl);
                    output.Append("so.addParam('allowScriptAccess', 'sameDomain');\n");
                    output.AppendFormat("so.write('{0}');\n", ClientID);
                    output.Append("</script>\n");
                    output.Append("<noscript>\n");
                }

                output.AppendFormat("<object classid='clsid:d27cdb6e-ae6d-11cf-96b8-444553540000' codebase='{0}://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=8,0,0,0'", _protocol);
                output.AppendFormat("width='{0}' height='{1}' id='ie_chart_{2}' align='middle'>\n", _width, _height, ClientID);
                output.Append("<param name='allowScriptAccess' value='sameDomain' />\n");
                output.AppendFormat("<param name='movie' value='{0}&amp;width={1}&amp;height={2}&data={3}' />",
                    ofcResource, _width, _height, dataUrl);
                output.Append("<param name='quality' value='high' />\n");
                output.Append("<param name='bgcolor' value='#FFFFFF' />\n");
                output.AppendFormat("<embed src='{0}&amp;data={1}' quality='high' bgcolor='#FFFFFF' width='{2}' height='{3}' name='{4}' align='middle' allowScriptAccess='sameDomain'",
                    ofcResource, dataUrl, _width, _height, ClientID);
                output.AppendFormat(" type='application/x-shockwave-flash' pluginspage='{0}://www.macromedia.com/go/getflashplayer' id='chart_{1}' />", _protocol, ClientID);
                output.Append("</object>\n");

                if (_useSwfObject)
                {
                    output.Append("</noscript>");
                }
                writer.Write(output.ToString());
            }
            else
            {
                writer.Write(string.Format("<div style='width:{0}px; height: {1}px;'>", Width, Height));
                writer.Write(ID);
                writer.Write("</div>");
            }            
            base.Render(writer);
        }
    }
}
