using System.Collections.Generic;
using System.Text;

namespace ChartControl.Ofc
{
    public class DefaultOfcGraphDataModel<T> : IOfcGraphDataModel {
        private int index;
        private List<T> data;
        private AbstractOfcSeriesType seriesType = new OfcLineSeriesType();

        public DefaultOfcGraphDataModel()
            : this(new List<T>())
        {
        }

        public DefaultOfcGraphDataModel(List<T> data)
        {
            this.data = data;
        }

        public int Index
        {
            get { return index; }
            set
            {
                index = value;
                if (seriesType != null)
                    seriesType.Index = index;
            }
        }

        public AbstractOfcSeriesType SeriesType
        {
            get { return seriesType; }
            set { seriesType = value; }
        }


        public List<T> Data
        {
            get { return data; }
            set { data = value; }
        }
        
        public string Render() {
            StringBuilder values = new StringBuilder();

            values.Append(seriesType.Render());
            values.Append("&values");

            if (Index > 1)
            {
                values.Append("_" + Index);
            }
            values.Append("=");

            for (int i = 0; i < data.Count; i++)
            {
                T item = data[i];
                if (!typeof(T).IsValueType && string.IsNullOrEmpty(item as string))
                    continue;
                values.Append(item + ",");
            }
            if (values[values.Length - 1] == ',')
                values.Remove(values.Length - 1, 1);
            values.Append("&\r\n");

            return values.ToString();
        }
    }
}