using System.Collections.Generic;
using System.Text;

namespace ChartControl.Ofc
{
    public class OfcGraphController : OfcGraphController<string>
    {
    }

    public class OfcGraphController<TLabel> : IOfcRenderer
    {
        private OfcTitle title = new OfcTitle();
        private OfcGraphLegend xLegend = new OfcGraphLegend(OfcGraphLegend.X_LEGEND);
        private OfcGraphLegend yLegend = new OfcGraphLegend(OfcGraphLegend.Y_LEGEND);
        private OfcGraphLabelStyle xLabelStyle = new OfcGraphLabelStyle(OfcGraphLabelStyle.X_LABEL_STYLE);
        private OfcGraphLabelStyle yLabelStyle = new OfcGraphLabelStyle(OfcGraphLabelStyle.Y_LABEL_STYLE);
        private OfcGraphTicks xTicks = new OfcGraphTicks(OfcGraphTicks.X_TICKS);
        private OfcGraphTicks yTicks = new OfcGraphTicks(OfcGraphTicks.Y_TICKS);
        private OfcGraphColor color = new OfcGraphColor();
        private OfcGraphMin yMin = new OfcGraphMin();
        private OfcGraphMax yMax = new OfcGraphMax();
        private OfcGraphLabels<TLabel> labels = new OfcGraphLabels<TLabel>();

        private List<IOfcGraphDataModel> models = new List<IOfcGraphDataModel>();

        public void Add(IOfcGraphDataModel dataModel)
        {
            if (dataModel != null)
            {
                models.Add(dataModel);
                dataModel.Index = models.Count;
            }
        }

        public void Clear()
        {
            models.Clear();
        }


        public OfcTitle Title
        {
            get { return title; }
            set { title = value; }
        }

        public OfcGraphLegend XLegend
        {
            get { return xLegend; }
            set { xLegend = value; }
        }

        public OfcGraphLegend YLegend
        {
            get { return yLegend; }
            set { yLegend = value; }
        }

        public OfcGraphLabelStyle XLabelStyle
        {
            get { return xLabelStyle; }
            set { xLabelStyle = value; }
        }

        public OfcGraphLabelStyle YLabelStyle
        {
            get { return yLabelStyle; }
            set { yLabelStyle = value; }
        }

        public OfcGraphTicks XTicks
        {
            get { return xTicks; }
            set { xTicks = value; }
        }

        public OfcGraphTicks YTicks
        {
            get { return yTicks; }
            set { yTicks = value; }
        }

        public OfcGraphColor Color
        {
            get { return color; }
            set { color = value; }
        }

        public OfcGraphMin YMin
        {
            get { return yMin; }
            set { yMin = value; }
        }

        public OfcGraphMax YMax
        {
            get { return yMax; }
            set { yMax = value; }
        }

        public OfcGraphLabels<TLabel> Labels
        {
            get { return labels; }
            set { labels = value; }
        }

        public string Render()
        {
            StringBuilder output = new StringBuilder();
            output
                .Append(title.Render())
                .Append(xLegend.Render())
                .Append(yLegend.Render())
                .Append(color.Render())
                .Append(xLabelStyle.Render())
                .Append(yLabelStyle.Render())
                .Append(xTicks.Render())
                .Append(yTicks.Render())
                .Append(yMin.Render())
                .Append(yMax.Render())
                .Append(labels.Render());

            for (int i = 0; i < models.Count; i++)
            {
                IOfcGraphDataModel model = models[i];
                output.Append(model.Render());
            }

            return output.ToString();
        }
    }
}